api.system.components.runtime.v1.instance.test_helpers.instance_install package — Argus-Toolbelt 1.0 documentation

# api.system.components.runtime.v1.instance.test_helpers.instance_install package

## Submodules

## api.system.components.runtime.v1.instance.test_helpers.instance_install.get_container_performance module

`api.system.components.runtime.v1.instance.test_helpers.instance_install.get_container_performance.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/performance, respond with HTTP 403

`api.system.components.runtime.v1.instance.test_helpers.instance_install.get_container_performance.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/performance, respond with HTTP 404

`api.system.components.runtime.v1.instance.test_helpers.instance_install.get_container_performance.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/performance, respond with HTTP 200

`api.system.components.runtime.v1.instance.test_helpers.instance_install.get_container_performance.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/performance, respond with HTTP 401

## api.system.components.runtime.v1.instance.test_helpers.instance_install.get_instance_status module

`api.system.components.runtime.v1.instance.test_helpers.instance_install.get_instance_status.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/status, respond with HTTP 403

`api.system.components.runtime.v1.instance.test_helpers.instance_install.get_instance_status.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/status, respond with HTTP 404

`api.system.components.runtime.v1.instance.test_helpers.instance_install.get_instance_status.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/status, respond with HTTP 200

`api.system.components.runtime.v1.instance.test_helpers.instance_install.get_instance_status.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/status, respond with HTTP 401

## api.system.components.runtime.v1.instance.test_helpers.instance_install.install module

`api.system.components.runtime.v1.instance.test_helpers.instance_install.install.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/install, respond with HTTP 403

`api.system.components.runtime.v1.instance.test_helpers.instance_install.install.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/install, respond with HTTP 404

`api.system.components.runtime.v1.instance.test_helpers.instance_install.install.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/install, respond with HTTP 200

`api.system.components.runtime.v1.instance.test_helpers.instance_install.install.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/install, respond with HTTP 401

## api.system.components.runtime.v1.instance.test_helpers.instance_install.reboot module

`api.system.components.runtime.v1.instance.test_helpers.instance_install.reboot.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/reboot, respond with HTTP 403

`api.system.components.runtime.v1.instance.test_helpers.instance_install.reboot.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/reboot, respond with HTTP 404

`api.system.components.runtime.v1.instance.test_helpers.instance_install.reboot.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/reboot, respond with HTTP 200

`api.system.components.runtime.v1.instance.test_helpers.instance_install.reboot.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/reboot, respond with HTTP 401

## api.system.components.runtime.v1.instance.test_helpers.instance_install.refresh_instance_status module

`api.system.components.runtime.v1.instance.test_helpers.instance_install.refresh_instance_status.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/status/refresh, respond with HTTP 403

`api.system.components.runtime.v1.instance.test_helpers.instance_install.refresh_instance_status.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/status/refresh, respond with HTTP 404

`api.system.components.runtime.v1.instance.test_helpers.instance_install.refresh_instance_status.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/status/refresh, respond with HTTP 200

`api.system.components.runtime.v1.instance.test_helpers.instance_install.refresh_instance_status.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/status/refresh, respond with HTTP 401

## api.system.components.runtime.v1.instance.test_helpers.instance_install.start module

`api.system.components.runtime.v1.instance.test_helpers.instance_install.start.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/start, respond with HTTP 403

`api.system.components.runtime.v1.instance.test_helpers.instance_install.start.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/start, respond with HTTP 404

`api.system.components.runtime.v1.instance.test_helpers.instance_install.start.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/start, respond with HTTP 200

`api.system.components.runtime.v1.instance.test_helpers.instance_install.start.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/start, respond with HTTP 401

## api.system.components.runtime.v1.instance.test_helpers.instance_install.stop module

`api.system.components.runtime.v1.instance.test_helpers.instance_install.stop.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/stop, respond with HTTP 403

`api.system.components.runtime.v1.instance.test_helpers.instance_install.stop.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/stop, respond with HTTP 404

`api.system.components.runtime.v1.instance.test_helpers.instance_install.stop.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/stop, respond with HTTP 200

`api.system.components.runtime.v1.instance.test_helpers.instance_install.stop.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/stop, respond with HTTP 401

## api.system.components.runtime.v1.instance.test_helpers.instance_install.uninstall module

`api.system.components.runtime.v1.instance.test_helpers.instance_install.uninstall.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/uninstall, respond with HTTP 403

`api.system.components.runtime.v1.instance.test_helpers.instance_install.uninstall.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/uninstall, respond with HTTP 404

`api.system.components.runtime.v1.instance.test_helpers.instance_install.uninstall.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/uninstall, respond with HTTP 200

`api.system.components.runtime.v1.instance.test_helpers.instance_install.uninstall.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/instance/w+/uninstall, respond with HTTP 401

## Module contents